#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


from pyramid.i18n import TranslationStringFactory
_ = TranslationStringFactory('pyams_content')


def includeme(config):
    """Pyramid include"""

    from .include import include_package
    include_package(config)

    from pyams_content.interfaces import MANAGE_SITE_ROOT_PERMISSION, MANAGE_SITE_PERMISSION, MANAGE_TOOL_PERMISSION, \
        CREATE_CONTENT_PERMISSION, MANAGE_CONTENT_PERMISSION, COMMENT_CONTENT_PERMISSION, PUBLISH_CONTENT_PERMISSION
    from pyams_utils.interfaces import PUBLIC_PERMISSION, VIEW_PERMISSION, MANAGE_PERMISSION, \
        VIEW_SYSTEM_PERMISSION, MANAGE_SECURITY_PERMISSION, MANAGE_ROLES_PERMISSION

    # register custom permissions
    config.register_permission({'id': MANAGE_SITE_ROOT_PERMISSION,
                                'title': _("Manage site root")})
    config.register_permission({'id': MANAGE_SITE_PERMISSION,
                                'title': _("Manage site")})
    config.register_permission({'id': MANAGE_TOOL_PERMISSION,
                                'title': _("Manage tool")})
    config.register_permission({'id': CREATE_CONTENT_PERMISSION,
                                'title': _("Create content")})
    config.register_permission({'id': MANAGE_CONTENT_PERMISSION,
                                'title': _("Manage content")})
    config.register_permission({'id': COMMENT_CONTENT_PERMISSION,
                                'title': _("Comment content")})
    config.register_permission({'id': PUBLISH_CONTENT_PERMISSION,
                                'title': _("Publish content")})

    # register custom roles
    config.register_role({'id': 'pyams.Webmaster',
                          'title': _("Webmaster (role)"),
                          'permissions': {PUBLIC_PERMISSION, VIEW_PERMISSION, MANAGE_PERMISSION,
                                          VIEW_SYSTEM_PERMISSION, MANAGE_SECURITY_PERMISSION, MANAGE_ROLES_PERMISSION,
                                          MANAGE_SITE_ROOT_PERMISSION, MANAGE_SITE_PERMISSION, MANAGE_TOOL_PERMISSION,
                                          CREATE_CONTENT_PERMISSION, MANAGE_CONTENT_PERMISSION,
                                          COMMENT_CONTENT_PERMISSION, PUBLISH_CONTENT_PERMISSION},
                          'managers': {'system:admin', 'role:system.Manager', 'role:pyams.Webmaster'}})
    config.register_role({'id': 'pyams.Pilot',
                          'title': _("Pilot (role)"),
                          'permissions': {PUBLIC_PERMISSION, VIEW_PERMISSION, MANAGE_PERMISSION,
                                          VIEW_SYSTEM_PERMISSION, MANAGE_ROLES_PERMISSION,
                                          MANAGE_SITE_PERMISSION, MANAGE_TOOL_PERMISSION,
                                          MANAGE_CONTENT_PERMISSION, COMMENT_CONTENT_PERMISSION,
                                          PUBLISH_CONTENT_PERMISSION},
                          'managers': {'system:admin', 'role:system.Manager', 'role:pyams.Webmaster'}})
    config.register_role({'id': 'pyams.Manager',
                          'title': _("Manager (role)"),
                          'permissions': {PUBLIC_PERMISSION, VIEW_PERMISSION, MANAGE_PERMISSION,
                                          VIEW_SYSTEM_PERMISSION, MANAGE_CONTENT_PERMISSION,
                                          COMMENT_CONTENT_PERMISSION, PUBLISH_CONTENT_PERMISSION},
                          'managers': {'system:admin', 'role:system.Manager', 'role:pyams.Webmaster',
                                       'role:pyams.Pilot'}})
    config.register_role({'id': 'pyams.Owner',
                          'title': _("Creator (role)"),
                          'permissions': {PUBLIC_PERMISSION, VIEW_PERMISSION, MANAGE_PERMISSION,
                                          VIEW_SYSTEM_PERMISSION, MANAGE_ROLES_PERMISSION,
                                          MANAGE_CONTENT_PERMISSION, COMMENT_CONTENT_PERMISSION}})
    config.register_role({'id': 'pyams.Contributor',
                          'title': _("Contributor (role)"),
                          'permissions': {PUBLIC_PERMISSION, VIEW_PERMISSION, MANAGE_PERMISSION,
                                          VIEW_SYSTEM_PERMISSION,
                                          CREATE_CONTENT_PERMISSION, MANAGE_CONTENT_PERMISSION,
                                          COMMENT_CONTENT_PERMISSION},
                          'managers': {'system:admin', 'role:system.Manager', 'role:pyams.Webmaster',
                                       'role:pyams.Pilot', 'role:pyams.Owner'}})
    config.register_role({'id': 'pyams.Reader',
                          'title': _("Reader (role)"),
                          'permissions': {PUBLIC_PERMISSION, VIEW_PERMISSION, MANAGE_PERMISSION,
                                          VIEW_SYSTEM_PERMISSION, COMMENT_CONTENT_PERMISSION},
                          'managers': {'system:admin', 'role:system.Manager', 'role:pyams.Webmaster',
                                       'role:pyams.Pilot', 'role:pyams.Manager', 'role:pyams.Contributor'}})
    config.register_role({'id': 'pyams.Operator',
                          'title': _("Operator (role)"),
                          'permissions': {PUBLIC_PERMISSION, VIEW_PERMISSION, VIEW_SYSTEM_PERMISSION},
                          'managers': {'system:admin', 'role:system.Manager'}})
    config.register_role({'id': 'pyams.Guest',
                          'title': _("Guest user (role)"),
                          'permissions': {PUBLIC_PERMISSION, VIEW_PERMISSION},
                          'managers': {'system:admin', 'role:system.Manager', 'role:pyams.Webmaster',
                                       'role:pyams.Pilot', 'role:pyams.Manager', 'role:pyams.Contributor'}})
