#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from pyams_content.interfaces import MANAGE_CONTENT_PERMISSION
from pyams_content.shared.imagemap.interfaces import IWfImageMap, IImageMapArea
from pyams_skin.interfaces.viewlet import IWidgetTitleViewletManager
from pyams_skin.layer import IPyAMSLayer

# import packages
from pyams_content.component.links.zmi.widget import SingleLinkLinkSelectFieldWidget
from pyams_content.shared.imagemap import ImageMapArea
from pyams_content.shared.imagemap.zmi.container import ImagemapAreasContainerView
from pyams_content.shared.imagemap.zmi.widget import ImgareaInputFieldWidget
from pyams_form.form import AJAXAddForm, AJAXEditForm
from pyams_pagelet.pagelet import pagelet_config
from pyams_skin.viewlet.toolbar import ToolbarAction
from pyams_viewlet.viewlet import viewlet_config
from pyams_zmi.form import AdminDialogAddForm, AdminDialogEditForm
from pyramid.view import view_config
from z3c.form import field

from pyams_content import _


@viewlet_config(name='add-imagemap-area.action', context=IWfImageMap, layer=IPyAMSLayer,
                view=ImagemapAreasContainerView, manager=IWidgetTitleViewletManager,
                permission=MANAGE_CONTENT_PERMISSION, weight=1)
class ImagemapAreaAddAction(ToolbarAction):
    """Image map area add menu"""

    label = _("Add image area")

    url = 'add-area.html'
    modal_target = True

    def __new__(cls, context, request, view, manager):
        image = context.image
        if image:
            for value in image.values():
                if value:
                    return ToolbarAction.__new__(cls)
        return None


@pagelet_config(name='add-area.html', context=IWfImageMap, layer=IPyAMSLayer, permission=MANAGE_CONTENT_PERMISSION)
class ImagemapAreaAddForm(AdminDialogAddForm):
    """Imagemap area add form"""

    legend = _("Add new image area")
    dialog_class = 'modal-large'

    fields = field.Fields(IImageMapArea)
    fields['link'].widgetFactory = SingleLinkLinkSelectFieldWidget
    fields['area'].widgetFactory = ImgareaInputFieldWidget

    ajax_handler = 'add-area.json'
    edit_permission = MANAGE_CONTENT_PERMISSION

    def create(self, data):
        return ImageMapArea()

    def add(self, object):
        self.context.add_area(object)

    def nextURL(self):
        return 'areas.html'


@view_config(name='add-area.json', context=IWfImageMap, request_type=IPyAMSLayer,
             permission=MANAGE_CONTENT_PERMISSION, renderer='json', xhr=True)
class ImagemapAreaAJAXAddForm(AJAXAddForm, ImagemapAreaAddForm):
    """Image map area add form, JSON renderer"""


@pagelet_config(name='properties.html', context=IImageMapArea, layer=IPyAMSLayer, permission=MANAGE_CONTENT_PERMISSION)
class ImagemapAreaPropertiesEditForm(AdminDialogEditForm):
    """Image map area properties edit form"""

    legend = _("Edit image map properties")
    dialog_class = 'modal-large'

    fields = field.Fields(IImageMapArea)
    fields['link'].widgetFactory = SingleLinkLinkSelectFieldWidget
    fields['area'].widgetFactory = ImgareaInputFieldWidget

    ajax_handler = 'properties.json'
    edit_permission = MANAGE_CONTENT_PERMISSION


@view_config(name='properties.json', context=IImageMapArea, request_type=IPyAMSLayer,
             permission=MANAGE_CONTENT_PERMISSION, renderer='json', xhr=True)
class ImagemapAreaPropertiesAJAXEditForm(AJAXEditForm, ImagemapAreaPropertiesEditForm):
    """Image map properties edit form, JSON rendener"""
