#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from pyams_content.shared.common.interfaces import ISharedContent, IWfSharedContent, ISharedTool

# import packages
from pyams_sequence.schema import InternalReferencesList
from zope.interface import Interface, Attribute
from zope.schema import List, Choice, Bool
from zope.schema.vocabulary import SimpleVocabulary, SimpleTerm

from pyams_content import _


VIEW_CONTENT_TYPE = 'view'
VIEW_CONTENT_NAME = _('View')


CREATION_DATE_ORDER = 'creation_datetime'
UPDATE_DATE_ORDER = 'update_datetime'
PUBLICATION_DATE_ORDER = 'publication_datetime'
FIRSTPUBLICATION_DATE_ORDER = 'first_publication_datetime'

VIEW_ORDER = {CREATION_DATE_ORDER: _("Creation date"),
              UPDATE_DATE_ORDER: _("Last update date"),
              PUBLICATION_DATE_ORDER: _("Current publication date"),
              FIRSTPUBLICATION_DATE_ORDER: _("First publication date")}

VIEW_ORDER_VOCABULARY = SimpleVocabulary([SimpleTerm(v, title=t)
                                          for v, t in VIEW_ORDER.items()])


class IViewsManager(ISharedTool):
    """Views manager interface"""


class IWfView(IWfSharedContent):
    """View interface"""

    selected_content_types = List(title=_("Content types"),
                                  description=_("Selected content types; leave empty for all"),
                                  value_type=Choice(vocabulary='PyAMS content types'),
                                  required=False)

    order_by = Choice(title=_("Order by"),
                      description=_("Property to use to sort results"),
                      required=True,
                      vocabulary=VIEW_ORDER_VOCABULARY,
                      default=FIRSTPUBLICATION_DATE_ORDER)

    reversed_order = Bool(title=_("Reversed order?"),
                          description=_("If 'yes', items order will be reversed"),
                          required=True,
                          default=True)


class IView(ISharedContent):
    """Workflow managed view interface"""


class IViewExtension(Interface):
    """View query extension interface

    This interface is used to add features to views from external packages
    """

    def get_params(self, context):
        """Add params to catalog query"""

    weight = Attribute("Extension weight")

    def filter(self, context, items):
        """Filter items after catalog query"""


VIEW_REFERENCES_SETTINGS_KEY = 'pyams_content.view.references'


class IViewInternalReferencesSettings(Interface):
    """View internal references settings"""

    references = InternalReferencesList(title=_("Internal references"),
                                        description=_("List of internal references"),
                                        required=False)
