#
# Copyright (c) 2008-2017 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library
from persistent import Persistent

# import interfaces
from pyams_content.shared.view.interfaces import IViewInternalReferencesSettings, IWfView, VIEW_REFERENCES_SETTINGS_KEY, \
    IViewExtension
from zope.annotation.interfaces import IAnnotations

# import packages
from pyams_utils.adapter import adapter_config, ContextAdapter
from pyramid.threadlocal import get_current_registry
from zope.container.contained import Contained
from zope.interface import implementer
from zope.lifecycleevent import ObjectCreatedEvent
from zope.location import locate
from zope.schema.fieldproperty import FieldProperty


@implementer(IViewInternalReferencesSettings)
class ViewInternalReferencesSettings(Persistent, Contained):
    """View internal references settings"""

    references = FieldProperty(IViewInternalReferencesSettings['references'])


@adapter_config(context=IWfView, provides=IViewInternalReferencesSettings)
def ViewInternalReferencesSettingsFactory(view):
    """View internal references settings factory"""
    annotations = IAnnotations(view)
    settings = annotations.get(VIEW_REFERENCES_SETTINGS_KEY)
    if settings is None:
        settings = annotations[VIEW_REFERENCES_SETTINGS_KEY] = ViewInternalReferencesSettings()
        get_current_registry().notify(ObjectCreatedEvent(settings))
        locate(settings, view, '++view:references++')
    return settings


@adapter_config(name='references', context=IWfView, provides=IViewExtension)
class ViewInternalReferencesExtension(ContextAdapter):
    """View internal references extension"""

    def get_param(self, context):
        pass

    weight = 999

    def filter(self, context, items):
        return items
